@@ -74,12 +74,12 @@ class ConfusionMatrixWidget:
             else:
                 s = r"""
                     \text{Accuracy} = \dfrac{
-                        \color{purple}{$TP}
-                        + \color{orange}{$TN}
+                        \color{orange}{$TP}
+                        + \color{blue}{$TN}
                     }{
-                        \color{purple}{$TP}
-                        + \color{blue}{$FN}
-                        + \color{orange}{$TN}
+                        \color{orange}{$TP}
+                        + \color{purple}{$FN}
+                        + \color{blue}{$TN}
                         + \color{red}{$FP}
                     } = $SCORE
                 """
@@ -99,9 +99,9 @@ class ConfusionMatrixWidget:
             else:
                 s = r"""
                     \text{Precision} = \dfrac{
-                        \color{purple}{$TP}
+                        \color{orange}{$TP}
                     }{
-                        \color{purple}{$TP}
+                        \color{orange}{$TP}
                         + \color{red}{$FP}
                     } = $SCORE
                 """
@@ -119,10 +119,10 @@ class ConfusionMatrixWidget:
             else:
                 s = r"""
                     \text{Recall} = \dfrac{
-                        \color{purple}{$TP}
+                        \color{orange}{$TP}
                     }{
-                        \color{purple}{$TP}
-                        + \color{blue}{$FN}
+                        \color{orange}{$TP}
+                        + \color{purple}{$FN}
                     } = $SCORE
                 """
             temp = Template(s).substitute(TP=tp, FN=fn, SCORE=score)
@@ -180,7 +180,7 @@ class ConfusionMatrixWidget:
             self.__generate_cnf(self.t_widget.value, rot90=True)
 
             # Set colors
-            color_matrix = np.array([["blue", "orange"], ["purple", "red"]])
+            color_matrix = np.array([["purple", "blue"], ["orange", "red"]])
 
             # Create fig
             fig = plt.figure(figsize=(10, 10))  # noQA F841
